aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorLuis R. Rodriguez <mcgrof@winlab.rutgers.edu>2008-04-26 19:34:02 -0700
committerLuis R. Rodriguez <mcgrof@winlab.rutgers.edu>2008-04-26 19:34:02 -0700
commit5bc34f806f3524c542ce048e06c96ee75cb0edc8 (patch)
tree07095b90e7089d60c9e4b9d8ddbecbbd9c2bb7ad
parent3ef70fa080f6c2f5e761172bc8b58ad948137697 (diff)
downloadcompat-wireless-2.6-old-5bc34f806f3524c542ce048e06c96ee75cb0edc8.tar.gz
Add cdc_ether.c, rndis_wlan needs it. I've tested this
on 2.6.24, it needs testign on 2.6.22. This may have broken compiling on 2.6.22. Also on make unload grep for ^module. Signed-off-by: Luis R. Rodriguez <mcgrof@winlab.rutgers.edu>
-rw-r--r--Makefile2
-rw-r--r--config.mk3
-rwxr-xr-xscripts/admin-update.sh11
-rwxr-xr-xscripts/unload.sh5
4 files changed, 13 insertions, 8 deletions
diff --git a/Makefile b/Makefile
index 2bac6b1..98b40ee 100644
--- a/Makefile
+++ b/Makefile
@@ -102,6 +102,7 @@ install: uninstall modules
@$(MODPROBE) -l rt2500usb
@$(MODPROBE) -l rt61pci
@$(MODPROBE) -l rt73usb
+ @$(MODPROBE) -l cdc_ether
@$(MODPROBE) -l rndis_host
@$(MODPROBE) -l rndis_wlan
@$(MODPROBE) -l rtl8180
@@ -158,6 +159,7 @@ uninstall:
@$(MODPROBE) -l rt2500usb
@$(MODPROBE) -l rt61pci
@$(MODPROBE) -l rt73usb
+ @$(MODPROBE) -l cdc_ether
@$(MODPROBE) -l rndis_host
@$(MODPROBE) -l rndis_wlan
@$(MODPROBE) -l rtl8180
diff --git a/config.mk b/config.mk
index 171e43a..eef472b 100644
--- a/config.mk
+++ b/config.mk
@@ -129,9 +129,10 @@ ifeq ($(shell test $(KERNEL_SUBLEVEL) -gt 21 && echo yes),yes)
# All of these devices are based on Broadcom 4320 chip which
# is only wireless RNDIS chip known to date.
# Note: this depends on CONFIG_USB_NET_RNDIS_HOST and CONFIG_USB_NET_CDCETHER
-# it also requires a new RNDIS_HOST module which we add
+# it also requires new RNDIS_HOST and CDC_ETHER modules which we add
CONFIG_USB_NET_RNDIS_HOST=m
CONFIG_USB_NET_RNDIS_WLAN=m
+CONFIG_USB_NET_CDCETHER=m
endif
endif
diff --git a/scripts/unload.sh b/scripts/unload.sh
index 50765c0..b156107 100755
--- a/scripts/unload.sh
+++ b/scripts/unload.sh
@@ -17,7 +17,8 @@ MODULES="$MODULES rt2400pci rt2500pci rt61pci"
MODULES="$MODULES rt2500usb rt73usb"
MODULES="$MODULES rt2x00usb rt2x00lib"
MODULES="$MODULES rtl8180 rtl8187"
-MODULES="$MODULES rndis_wlan at76_usb"
+MODULES="$MODULES at76_usb"
+MODULES="$MODULES rndis_wlan rndis_host cdc_ether"
# eeprom_93cx6 is used by rt2x00 (rt61pci, rt2500pci, rt2400pci)
# and Realtek drivers ( rtl8187, rtl8180)
MODULES="$MODULES eeprom_93cx6"
@@ -41,7 +42,7 @@ if [ $? -eq 0 ]; then
fi
for i in $MODULES; do
- grep $i /proc/modules 2>&1 > /dev/null
+ grep ^$i /proc/modules 2>&1 > /dev/null
if [ $? -eq 0 ]; then
echo Unloading $i...
modprobe -r --ignore-remove $i
diff --git a/scripts/admin-update.sh b/scripts/admin-update.sh
index 7373c86..dc6ba70 100755
--- a/scripts/admin-update.sh
+++ b/scripts/admin-update.sh
@@ -117,12 +117,13 @@ for i in $DRIVERS; do
rm -f $i/*.mod.c
done
-# For rndis_wlan, we need a new rndis_host
+# For rndis_wlan, we need a new rndis_host and cdc_ether
+RNDIS_REQS="Makefile rndis_host.c cdc_ether.c"
DIR="drivers/net/usb"
-echo "Copying $GIT_TREE/$DIR/rndis_host.c"
-cp $GIT_TREE/$DIR/rndis_host.c $DIR/
-echo "Copying $GIT_TREE/$DIR/Makefile"
-cp $GIT_TREE/$DIR/Makefile $DIR/
+for i in $RNDIS_REQS; do
+ echo "Copying $GIT_TREE/$DIR/$i"
+ cp $GIT_TREE/$DIR/$i $DIR/
+done
# Misc
mkdir -p drivers/misc/